@@ -4,11 +4,11 @@ from airflow.exceptions import AirflowException
 
 
 @dataclass
-class PowerBiDatasetRefreshDetails():
+class PowerBiDatasetRefreshDetails:
     request_id: str
     status: str
-    end_time: str
-    error: str
+    end_time: str | None
+    error: str | None
 
 
 class PowerBIDatasetRefreshException(AirflowException):
